@@ -27,13 +27,13 @@
 #include "kslavelauncheradaptor.h"
 
 #include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <errno.h>
+#include <qplatformdefs.h>
 #include <signal.h>
+#include <errno.h>
 
 #if HAVE_X11
 #include <kstartupinfo.h>
+#include <QGuiApplication>
 #endif
 
 #include <QDBusConnectionInterface>
@@ -56,6 +56,12 @@
 #include <kio/global.h>
 #include <kio/slaveinterface.h>
 
+#ifdef Q_OS_WIN
+#include <qt_windows.h>
+//windows.h feels like defining this...
+#undef interface
+#endif
+
 // Dispose slaves after being idle for SLAVE_MAX_IDLE seconds
 #define SLAVE_MAX_IDLE  30
 
@@ -95,6 +101,7 @@ KLauncher::KLauncher()
 {
 #if HAVE_X11
     mCached_dpy = NULL;
+    mIsX11 = QGuiApplication::platformName() == QStringLiteral("xcb");
 #endif
     Q_ASSERT(g_klauncher_self == NULL);
     g_klauncher_self = this;
@@ -464,7 +471,7 @@ KLauncher::requestDone(KLaunchRequest *request)
         requestResult.pid = 0;
 
 #if HAVE_X11
-        if (!request->startup_dpy.isEmpty()) {
+        if (!request->startup_dpy.isEmpty() && mIsX11) {
             Display *dpy = NULL;
             if ((mCached_dpy != NULL) &&
                     (request->startup_dpy == XDisplayString(mCached_dpy))) {
@@ -495,7 +502,7 @@ KLauncher::requestDone(KLaunchRequest *request)
             requestResult.dbusName.clear();
         }
         Q_ASSERT(!requestResult.error.isNull());
-        Q_PID stream_pid = requestResult.pid;
+        quintptr stream_pid = requestResult.pid;
         QDBusConnection::sessionBus().send(request->transaction.createReply(QVariantList() << requestResult.result
                                            << requestResult.dbusName
                                            << requestResult.error
@@ -547,7 +554,11 @@ KLauncher::requestStart(KLaunchRequest *request)
     if (!process->waitForStarted()) {
         processRequestReturn(LAUNCHER_ERROR, "");
     } else {
+#ifndef Q_OS_WIN
         request->pid = process->pid();
+#else
+        request->pid = process->pid()->dwProcessId;
+#endif
         QByteArray data((char *)&request->pid, sizeof(int));
         processRequestReturn(LAUNCHER_OK, data);
     }
@@ -572,7 +583,7 @@ KLauncher::requestStart(KLaunchRequest *request)
     }
     appendLong(requestData, 0); // avoid_loops, always false here
 #if HAVE_X11
-    bool startup_notify = !request->startup_id.isNull() && request->startup_id != "0";
+    bool startup_notify = mIsX11 && !request->startup_id.isNull() && request->startup_id != "0";
     if (startup_notify) {
         requestData.append(request->startup_id).append('\0');
     }
@@ -775,6 +786,9 @@ KLauncher::send_service_startup_info(KLaunchRequest *request, KService::Ptr serv
                                      const QStringList &envs)
 {
 #if HAVE_X11
+    if (!mIsX11) {
+        return;
+    }
     request->startup_id = "0";// krazy:exclude=doublequote_chars
     if (startup_id == "0") {
         return;
@@ -838,7 +852,7 @@ KLauncher::cancel_service_startup_info(KLaunchRequest *request, const QByteArray
     if (request != NULL) {
         request->startup_id = "0";    // krazy:exclude=doublequote_chars
     }
-    if (!startup_id.isEmpty() && startup_id != "0") {
+    if (!startup_id.isEmpty() && startup_id != "0" && mIsX11) {
         QString dpy_str;
         foreach (const QString &env, envs) {
             if (env.startsWith(QLatin1String("DISPLAY="))) {
